@@ -1,6 +1,8 @@
 package Moo::_mro;
 
-if ($] > 5.010) {
+local $@;
+
+if ($] >= 5.010) {
   require mro;
 } else {
   require MRO::Compat;
